==> jc-1.4.0.tar.gz: java/awt/Container__24GfxPrintVisitor.h <==
// class java.awt.Container$GfxPrintVisitor

// class file dependencies
// @dep_class f32d477c8a38e29c java_awt_Container__24GfxPrintVisitor
// @dep_class a0c7f2977640055f java_awt_Container__24GfxVisitor
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_Container__24GfxVisitor

#include "java/awt/Container__24GfxVisitor.h"

#ifndef _JC_java_awt_Container__24GfxPrintVisitor_H_
#define _JC_java_awt_Container__24GfxPrintVisitor_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Container__24GfxVisitor$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_Container__24GfxPrintVisitor$sub_refs	_jc_java_awt_Container__24GfxPrintVisitor$sub_refs;
typedef struct _jc_java_awt_Container__24GfxPrintVisitor$sub_nonrefs	_jc_java_awt_Container__24GfxPrintVisitor$sub_nonrefs;
typedef struct _jc_java_awt_Container__24GfxPrintVisitor$refs	_jc_java_awt_Container__24GfxPrintVisitor$refs;
typedef struct _jc_java_awt_Container__24GfxPrintVisitor$nonrefs	_jc_java_awt_Container__24GfxPrintVisitor$nonrefs;
typedef struct _jc_java_awt_Container__24GfxPrintVisitor$object	_jc_java_awt_Container__24GfxPrintVisitor$object;

typedef struct _jc_java_awt_Container__24GfxPrintVisitor$fields_struct	_jc_java_awt_Container__24GfxPrintVisitor$fields_struct;
typedef const struct _jc_java_awt_Container__24GfxPrintVisitor$vmethods	_jc_java_awt_Container__24GfxPrintVisitor$vmethods;
typedef const struct _jc_java_awt_Container__24GfxPrintVisitor$vtable	_jc_java_awt_Container__24GfxPrintVisitor$vtable;
typedef const struct _jc_java_awt_Container__24GfxPrintVisitor$vtype	_jc_java_awt_Container__24GfxPrintVisitor$vtype;

// Class fields structure
struct _jc_java_awt_Container__24GfxPrintVisitor$fields_struct {
	struct _jc_java_awt_Container__24GfxVisitor$object	*INSTANCE;
};
extern _jc_java_awt_Container__24GfxPrintVisitor$fields_struct _jc_java_awt_Container__24GfxPrintVisitor$class_fields;

// Constructors
extern void _jc_java_awt_Container__24GfxPrintVisitor$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_Container__24GfxPrintVisitor$object *);

// Virtual methods
extern void _jc_java_awt_Container__24GfxPrintVisitor$method$visit$0c80e38e76a498e6(_jc_env *, struct _jc_java_awt_Container__24GfxPrintVisitor$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_Container__24GfxPrintVisitor$method_info$visit$0c80e38e76a498e6;

// Static methods
extern void _jc_java_awt_Container__24GfxPrintVisitor$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_awt_Container__24GfxPrintVisitor$vmethods {
	void	(*visit$0c80e38e76a498e6)(_jc_env *, struct _jc_java_awt_Container__24GfxPrintVisitor$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *);
};

// Vtable
struct _jc_java_awt_Container__24GfxPrintVisitor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Container__24GfxVisitor$vmethods	java_awt_Container__24GfxVisitor;
	_jc_java_awt_Container__24GfxPrintVisitor$vmethods	java_awt_Container__24GfxPrintVisitor;
};

// Vtype
struct _jc_java_awt_Container__24GfxPrintVisitor$vtype {
	_jc_type			type;
	_jc_java_awt_Container__24GfxPrintVisitor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Container__24GfxPrintVisitor$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_Container__24GfxPrintVisitor$refs {
    _jc_java_awt_Container__24GfxPrintVisitor$sub_refs	java_awt_Container__24GfxPrintVisitor;
    _jc_java_awt_Container__24GfxVisitor$sub_refs	java_awt_Container__24GfxVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Container__24GfxPrintVisitor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Container__24GfxPrintVisitor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Container__24GfxVisitor$sub_nonrefs	java_awt_Container__24GfxVisitor;
    _jc_java_awt_Container__24GfxPrintVisitor$sub_nonrefs	java_awt_Container__24GfxPrintVisitor;
};

// Object instance structure
struct _jc_java_awt_Container__24GfxPrintVisitor$object {
	_jc_java_awt_Container__24GfxPrintVisitor$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Container__24GfxPrintVisitor$vtype	*vtype;
	_jc_java_awt_Container__24GfxPrintVisitor$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Container__24GfxPrintVisitor$vtype _jc_java_awt_Container__24GfxPrintVisitor$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Container__24GfxPrintVisitor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Container__24GfxPrintVisitor$class_object;

#endif	/* _JC_java_awt_Container__24GfxPrintVisitor_H_ */

==> jc-1.4.6.tar.gz: java/awt/Container__24GfxPrintVisitor.h <==
// class java.awt.Container$GfxPrintVisitor

// class file dependencies
// @dep_class f32d477c8a38e29c java_awt_Container__24GfxPrintVisitor
// @dep_class a0c7f2977640055f java_awt_Container__24GfxVisitor
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_Container__24GfxVisitor

#include "java/awt/Container__24GfxVisitor.h"

#ifndef _JC_java_awt_Container__24GfxPrintVisitor_H_
#define _JC_java_awt_Container__24GfxPrintVisitor_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Container__24GfxVisitor$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_Container__24GfxPrintVisitor$sub_refs	_jc_java_awt_Container__24GfxPrintVisitor$sub_refs;
typedef struct _jc_java_awt_Container__24GfxPrintVisitor$sub_nonrefs	_jc_java_awt_Container__24GfxPrintVisitor$sub_nonrefs;
typedef struct _jc_java_awt_Container__24GfxPrintVisitor$refs	_jc_java_awt_Container__24GfxPrintVisitor$refs;
typedef struct _jc_java_awt_Container__24GfxPrintVisitor$nonrefs	_jc_java_awt_Container__24GfxPrintVisitor$nonrefs;
typedef struct _jc_java_awt_Container__24GfxPrintVisitor$object	_jc_java_awt_Container__24GfxPrintVisitor$object;

typedef struct _jc_java_awt_Container__24GfxPrintVisitor$fields_struct	_jc_java_awt_Container__24GfxPrintVisitor$fields_struct;
typedef const struct _jc_java_awt_Container__24GfxPrintVisitor$vmethods	_jc_java_awt_Container__24GfxPrintVisitor$vmethods;
typedef const struct _jc_java_awt_Container__24GfxPrintVisitor$vtable	_jc_java_awt_Container__24GfxPrintVisitor$vtable;
typedef const struct _jc_java_awt_Container__24GfxPrintVisitor$vtype	_jc_java_awt_Container__24GfxPrintVisitor$vtype;

// Class fields structure
struct _jc_java_awt_Container__24GfxPrintVisitor$fields_struct {
	struct _jc_java_awt_Container__24GfxVisitor$object	*INSTANCE;
};
extern _jc_java_awt_Container__24GfxPrintVisitor$fields_struct _jc_java_awt_Container__24GfxPrintVisitor$class_fields;

// Constructors
extern void _jc_java_awt_Container__24GfxPrintVisitor$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_Container__24GfxPrintVisitor$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_Container__24GfxPrintVisitor$method$visit$0c80e38e76a498e6(_jc_env *, struct _jc_java_awt_Container__24GfxPrintVisitor$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_Container__24GfxPrintVisitor$method_info$visit$0c80e38e76a498e6;

// Static methods
extern void _jc_java_awt_Container__24GfxPrintVisitor$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_Container__24GfxPrintVisitor$vmethods {
	void	(*visit$0c80e38e76a498e6)(_jc_env *, struct _jc_java_awt_Container__24GfxPrintVisitor$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_Container__24GfxPrintVisitor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Container__24GfxVisitor$vmethods	java_awt_Container__24GfxVisitor;
	_jc_java_awt_Container__24GfxPrintVisitor$vmethods	java_awt_Container__24GfxPrintVisitor;
};

// Vtype
struct _jc_java_awt_Container__24GfxPrintVisitor$vtype {
	_jc_type			type;
	_jc_java_awt_Container__24GfxPrintVisitor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Container__24GfxPrintVisitor$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_Container__24GfxPrintVisitor$refs {
    _jc_java_awt_Container__24GfxPrintVisitor$sub_refs	java_awt_Container__24GfxPrintVisitor;
    _jc_java_awt_Container__24GfxVisitor$sub_refs	java_awt_Container__24GfxVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Container__24GfxPrintVisitor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Container__24GfxPrintVisitor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Container__24GfxVisitor$sub_nonrefs	java_awt_Container__24GfxVisitor;
    _jc_java_awt_Container__24GfxPrintVisitor$sub_nonrefs	java_awt_Container__24GfxPrintVisitor;
};

// Object instance structure
struct _jc_java_awt_Container__24GfxPrintVisitor$object {
	_jc_java_awt_Container__24GfxPrintVisitor$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Container__24GfxPrintVisitor$vtype	*vtype;
	_jc_java_awt_Container__24GfxPrintVisitor$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Container__24GfxPrintVisitor$vtype _jc_java_awt_Container__24GfxPrintVisitor$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Container__24GfxPrintVisitor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Container__24GfxPrintVisitor$class_object;

#endif	/* _JC_java_awt_Container__24GfxPrintVisitor_H_ */
